==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaKierujaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypDecyzjiKierujacej;
import pl.topteam.dps.enums.ZasadyWydawaniaDecyzjiKierujacych;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DecyzjaKierujaca extends GenericDPSObject {
    /**
     * DECYZJA_KIERUJACA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DECYZJA_KIERUJACA.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_KIERUJACA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * DECYZJA_KIERUJACA.POSTANOWIENIE_SADU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long postanowienieSaduId;

    /**
     * DECYZJA_KIERUJACA.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * DECYZJA_KIERUJACA.DATA_WPLYWU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWplywu;

    /**
     * DECYZJA_KIERUJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * DECYZJA_KIERUJACA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DECYZJA_KIERUJACA.WYDANA_NA_ZASADACH
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private ZasadyWydawaniaDecyzjiKierujacych wydanaNaZasadach;

    /**
     * DECYZJA_KIERUJACA.PRIORYTET
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer priorytet;

    /**
     * DECYZJA_KIERUJACA.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypDecyzjiKierujacej typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_KIERUJACA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_KIERUJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_KIERUJACA.KTO_WYDAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_KIERUJACA.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_KIERUJACA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DECYZJA_KIERUJACA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DECYZJA_KIERUJACA.POSTANOWIENIE_SADU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPostanowienieSaduId() {
        return postanowienieSaduId;
    }

    /**
     * DECYZJA_KIERUJACA.POSTANOWIENIE_SADU_ID
     *
     * @param postanowienieSaduId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPostanowienieSaduId(Long postanowienieSaduId) {
        this.postanowienieSaduId = postanowienieSaduId;
    }

    /**
     * @return DECYZJA_KIERUJACA.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * DECYZJA_KIERUJACA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return DECYZJA_KIERUJACA.DATA_WPLYWU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWplywu() {
        return dataWplywu;
    }

    /**
     * DECYZJA_KIERUJACA.DATA_WPLYWU
     *
     * @param dataWplywu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWplywu(Date dataWplywu) {
        this.dataWplywu = dataWplywu;
    }

    /**
     * @return DECYZJA_KIERUJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_KIERUJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_KIERUJACA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_KIERUJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_KIERUJACA.WYDANA_NA_ZASADACH
     * @mbggenerated 2014-03-10 10:45:37
     */
    public ZasadyWydawaniaDecyzjiKierujacych getWydanaNaZasadach() {
        return wydanaNaZasadach;
    }

    /**
     * DECYZJA_KIERUJACA.WYDANA_NA_ZASADACH
     *
     * @param wydanaNaZasadach
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWydanaNaZasadach(ZasadyWydawaniaDecyzjiKierujacych wydanaNaZasadach) {
        this.wydanaNaZasadach = wydanaNaZasadach;
    }

    /**
     * @return DECYZJA_KIERUJACA.PRIORYTET
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getPriorytet() {
        return priorytet;
    }

    /**
     * DECYZJA_KIERUJACA.PRIORYTET
     *
     * @param priorytet
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPriorytet(Integer priorytet) {
        this.priorytet = priorytet;
    }

    /**
     * @return DECYZJA_KIERUJACA.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypDecyzjiKierujacej getTyp() {
        return typ;
    }

    /**
     * DECYZJA_KIERUJACA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypDecyzjiKierujacej typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaKierujaca other = (DecyzjaKierujaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPostanowienieSaduId() == null ? other.getPostanowienieSaduId() == null : this.getPostanowienieSaduId().equals(other.getPostanowienieSaduId()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getDataWplywu() == null ? other.getDataWplywu() == null : this.getDataWplywu().equals(other.getDataWplywu()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getWydanaNaZasadach() == null ? other.getWydanaNaZasadach() == null : this.getWydanaNaZasadach().equals(other.getWydanaNaZasadach()))
            && (this.getPriorytet() == null ? other.getPriorytet() == null : this.getPriorytet().equals(other.getPriorytet()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPostanowienieSaduId() == null) ? 0 : getPostanowienieSaduId().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getDataWplywu() == null) ? 0 : getDataWplywu().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getWydanaNaZasadach() == null) ? 0 : getWydanaNaZasadach().hashCode());
        result = prime * result + ((getPriorytet() == null) ? 0 : getPriorytet().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", postanowienieSaduId=").append(postanowienieSaduId);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", dataWplywu=").append(dataWplywu);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", nr=").append(nr);
        sb.append(", wydanaNaZasadach=").append(wydanaNaZasadach);
        sb.append(", priorytet=").append(priorytet);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaKierujaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypDecyzjiKierujacej;
import pl.topteam.dps.enums.ZasadyWydawaniaDecyzjiKierujacych;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DecyzjaKierujaca extends GenericDPSObject {
    /**
     * DECYZJA_KIERUJACA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DECYZJA_KIERUJACA.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_KIERUJACA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * DECYZJA_KIERUJACA.POSTANOWIENIE_SADU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long postanowienieSaduId;

    /**
     * DECYZJA_KIERUJACA.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * DECYZJA_KIERUJACA.DATA_WPLYWU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWplywu;

    /**
     * DECYZJA_KIERUJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * DECYZJA_KIERUJACA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DECYZJA_KIERUJACA.WYDANA_NA_ZASADACH
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private ZasadyWydawaniaDecyzjiKierujacych wydanaNaZasadach;

    /**
     * DECYZJA_KIERUJACA.PRIORYTET
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer priorytet;

    /**
     * DECYZJA_KIERUJACA.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypDecyzjiKierujacej typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_KIERUJACA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_KIERUJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_KIERUJACA.KTO_WYDAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_KIERUJACA.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_KIERUJACA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DECYZJA_KIERUJACA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DECYZJA_KIERUJACA.POSTANOWIENIE_SADU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPostanowienieSaduId() {
        return postanowienieSaduId;
    }

    /**
     * DECYZJA_KIERUJACA.POSTANOWIENIE_SADU_ID
     *
     * @param postanowienieSaduId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPostanowienieSaduId(Long postanowienieSaduId) {
        this.postanowienieSaduId = postanowienieSaduId;
    }

    /**
     * @return DECYZJA_KIERUJACA.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * DECYZJA_KIERUJACA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return DECYZJA_KIERUJACA.DATA_WPLYWU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWplywu() {
        return dataWplywu;
    }

    /**
     * DECYZJA_KIERUJACA.DATA_WPLYWU
     *
     * @param dataWplywu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWplywu(Date dataWplywu) {
        this.dataWplywu = dataWplywu;
    }

    /**
     * @return DECYZJA_KIERUJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_KIERUJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_KIERUJACA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_KIERUJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_KIERUJACA.WYDANA_NA_ZASADACH
     * @mbggenerated 2014-03-13 16:02:38
     */
    public ZasadyWydawaniaDecyzjiKierujacych getWydanaNaZasadach() {
        return wydanaNaZasadach;
    }

    /**
     * DECYZJA_KIERUJACA.WYDANA_NA_ZASADACH
     *
     * @param wydanaNaZasadach
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWydanaNaZasadach(ZasadyWydawaniaDecyzjiKierujacych wydanaNaZasadach) {
        this.wydanaNaZasadach = wydanaNaZasadach;
    }

    /**
     * @return DECYZJA_KIERUJACA.PRIORYTET
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getPriorytet() {
        return priorytet;
    }

    /**
     * DECYZJA_KIERUJACA.PRIORYTET
     *
     * @param priorytet
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPriorytet(Integer priorytet) {
        this.priorytet = priorytet;
    }

    /**
     * @return DECYZJA_KIERUJACA.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypDecyzjiKierujacej getTyp() {
        return typ;
    }

    /**
     * DECYZJA_KIERUJACA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypDecyzjiKierujacej typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaKierujaca other = (DecyzjaKierujaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPostanowienieSaduId() == null ? other.getPostanowienieSaduId() == null : this.getPostanowienieSaduId().equals(other.getPostanowienieSaduId()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getDataWplywu() == null ? other.getDataWplywu() == null : this.getDataWplywu().equals(other.getDataWplywu()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getWydanaNaZasadach() == null ? other.getWydanaNaZasadach() == null : this.getWydanaNaZasadach().equals(other.getWydanaNaZasadach()))
            && (this.getPriorytet() == null ? other.getPriorytet() == null : this.getPriorytet().equals(other.getPriorytet()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPostanowienieSaduId() == null) ? 0 : getPostanowienieSaduId().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getDataWplywu() == null) ? 0 : getDataWplywu().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getWydanaNaZasadach() == null) ? 0 : getWydanaNaZasadach().hashCode());
        result = prime * result + ((getPriorytet() == null) ? 0 : getPriorytet().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", postanowienieSaduId=").append(postanowienieSaduId);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", dataWplywu=").append(dataWplywu);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", nr=").append(nr);
        sb.append(", wydanaNaZasadach=").append(wydanaNaZasadach);
        sb.append(", priorytet=").append(priorytet);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
